package Passwd::Keyring::Auto::App::PasswordClear;
use strict; use warnings;
use MooseX::App::Command;

extends 'Passwd::Keyring::Auto::App';

command_short_description q[NOT YET IMPLEMENTED];
command_long_description q[NOT YET IMPLEMENTED];

sub run {
  my ($self, $opt, $arg) = @_;
}

1;
